==> react-combine-providers-0.9.0.tgz: package/README.md <==
react-combine-providers
========================

In React.js, libraries such as ReactRouter, StyledComponents SSR, ReactHelmet and many other, needs providers in the root of the application. So usually entry file looks like as flying ducks in the sky

![example-of-flying-ducks](https://github.com/epranka/react-combine-providers/blob/master/resources/example-of-flying-ducks.png)

This module lets avoid it, and makes flying ducks more readable

![convert-flying-ducks-to-this](https://github.com/epranka/react-combine-providers/blob/master/resources/convert-flying-ducks-to-this.png)

### Install

```
npm install --save react-combine-providers
```

or

```
yarn install react-combine-providers
```

### Import module

```js
import { combineProviders } from "react-combine-providers";
```

### Usage

![usage-example](https://github.com/epranka/react-combine-providers/blob/master/resources/usage-example.png)

### Real example

![real-example](https://github.com/epranka/react-combine-providers/blob/master/resources/real-example.png)

### Author

Edvinas pranka

[@epranka](https://twitter.com/epranka)

https://www.kodmina.lt

# License

ISC License

Copyright (c) 2019 Edvinas Pranka(@epranka, https:///www.kodmina.lt)

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

==> react-combine-providers-0.9.1.tgz: package/README.md <==
react-combine-providers
========================

In React.js, libraries such as ReactRouter, StyledComponents SSR, ReactHelmet and many other, needs providers in the root of the application. So usually entry file looks like as flying ducks in the sky

![example-of-flying-ducks](https://raw.githubusercontent.com/epranka/react-combine-providers/master/resources/example-of-flying-ducks.png)

This module lets avoid it, and makes flying ducks more readable

![convert-flying-ducks-to-this](https://raw.githubusercontent.com/epranka/react-combine-providers/master/resources/convert-flying-ducks-to-this.png)

### Install

```
npm install --save react-combine-providers
```

or

```
yarn install react-combine-providers
```

### Import module

```js
import { combineProviders } from "react-combine-providers";
```

### Usage

![usage-example](https://raw.githubusercontent.com/epranka/react-combine-providers/master/resources/usage-example.png)

### Real example

![real-example](https://raw.githubusercontent.com/epranka/react-combine-providers/master/resources/real-example.png)

### Author

Edvinas pranka

[@epranka](https://twitter.com/epranka)

https://www.kodmina.lt

# License

ISC License

Copyright (c) 2019 Edvinas Pranka(@epranka, https:///www.kodmina.lt)

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
